==> coorpacademy-core-1.2.1.tgz: package/lib/errorHandler/index.js <==
'use strict';

var errTree = require('err-tree');
var _ = require('lodash');

var errorHandler = {};
errorHandler.logger = console;
/**
 * generate a unique error ID
 * @return {[type]} [description]
 */
errorHandler.generateId = function(suffix) {
    suffix = suffix || '';
    // nanosecond safe
    return 'ERR' + suffix + Date.now() + process.hrtime()[1];
};

errorHandler.CoorpError = errTree(function CoorpError() {
    errTree.BasicError.apply(this, arguments);
    this.id = errorHandler.generateId();
});

/**
 * check if NODE_ENV is safe
 * @return {[type]} [description]
 */
errorHandler.safeEnv = function() {
    return process.env.NODE_ENV === 'development' || process.env.NODE_ENV === 'test';
};

/**
 * add a unique error id
 * @param  {[type]} error [description]
 * @return {[type]}       [description]
 */
errorHandler.wrap = function(error) {
    error.id = error.id || errorHandler.generateId();
    return error;
};

/**
* prepare error for json transport
* @param  {[type]} err    [description]
* @return {[type]}        [description]
*/
errorHandler.cleanifyError = function(err) {
    var plainObject = {};
    Object.getOwnPropertyNames(err).forEach(function(key) {
        if (key === 'stack' && !errorHandler.safeEnv()) {
            return;
        }
        plainObject[key] = err[key];
    });
    return plainObject;
};

/**
* get an express hnadler
* @param  {[type]} options [errorView: 'pages/500' ]
* @return {[type]}         [description]
*/
errorHandler.expressErrorMiddleware = function(options) {
    options = _.defaults(options, {
        errorView: '500'
    });
    // NE JAMAIS ENLEVER next MEME SI PAS UTILISE
    /*jshint unused:false*/
    return function(err, req, res, next) {
        err = errorHandler.wrap(err);
        errorHandler.logger.error(err.id, err.stack || err);
        var error_response =  {
            id: err.id,
            type: err.type,
            code: err.code,
            status: 500,
            success: false,
            message: err.message,
            errors: [errorHandler.cleanifyError(err)]
        };
        if (errorHandler.safeEnv()) {
            error_response.stack = err.stack;
        }
        if (req.xhr) {
            return res.status(500).json(error_response);
        }
        else {
            return res.status(500).render(options.errorView, {
                error: error_response
            });
        }
    };
};

module.exports = errorHandler;

==> coorpacademy-core-1.3.1.tgz: package/lib/errorHandler/index.js <==
'use strict';

var errTree = require('err-tree');
var _ = require('lodash');

var errorHandler = {};
errorHandler.logger = console;
/**
 * generate a unique error ID
 * @return {[type]} [description]
 */
errorHandler.generateId = function(suffix) {
    suffix = suffix || '';
    // nanosecond safe
    return 'ERR' + suffix + Date.now() + process.hrtime()[1];
};

errorHandler.CoorpError = errTree(function CoorpError() {
    errTree.BasicError.apply(this, arguments);
    this.id = errorHandler.generateId();
});

/**
 * check if NODE_ENV is safe
 * @return {[type]} [description]
 */
errorHandler.safeEnv = function() {
    return process.env.NODE_ENV === 'development' || process.env.NODE_ENV === 'test';
};

/**
 * add a unique error id
 * @param  {[type]} err [description]
 * @return {[type]}       [description]
 */
errorHandler.wrap = function(err) {
    if (err instanceof String || typeof(err) === 'string') {
        return err;
    }
    err.id = err.id || errorHandler.generateId();
    return err;
};

/**
* prepare error for json transport
* @param  {[type]} err    [description]
* @return {[type]}        [description]
*/
errorHandler.cleanifyError = function(err) {
    if (err instanceof String || typeof(err) === 'string') {
        return err;
    }
    var plainObject = {};
    Object.getOwnPropertyNames(err).forEach(function(key) {
        if (key === 'stack' && !errorHandler.safeEnv()) {
            return;
        }
        plainObject[key] = err[key];
    });
    return plainObject;
};

/**
* get an express hnadler
* @param  {[type]} options [errorView: 'pages/500' ]
* @return {[type]}         [description]
*/
errorHandler.expressErrorMiddleware = function(options) {
    options = _.defaults(options, {
        errorView: '500'
    });
    // NE JAMAIS ENLEVER next MEME SI PAS UTILISE
    /*jshint unused:false*/
    return function(err, req, res, next) {
        if (res.headersSent) {
            res.end();
            // header already sent, can't write to stream
            return;
        }
        err = errorHandler.wrap(err);
        errorHandler.logger.error(err.id, err.stack || err);
        var error_response =  {
            id: err.id,
            type: err.type,
            code: err.code,
            status: 500,
            success: false,
            message: err.message,
            errors: [errorHandler.cleanifyError(err)]
        };
        if (errorHandler.safeEnv()) {
            error_response.stack = err.stack;
        }
        if (req.xhr) {
            return res.status(500).json(error_response);
        }
        else {
            return res.status(500).render(options.errorView, {
                error: error_response
            });
        }
    };
};

module.exports = errorHandler;
